@@ -304,7 +304,23 @@ armadillo.subset_definition <- function(reference_csv = NULL, vars = NULL) { # n
 #' @param target_project Project to upload subset to.
 #' @noRd
 .make_post_url <- function(target_project) {
-  return(sprintf("%sstorage/projects/%s/objects/link", .get_url(), target_project))
+  server_url <- .add_slash_if_missing(.get_url())
+  return(sprintf("%sstorage/projects/%s/objects/link", server_url, target_project))
+}
+
+#' Add a Slash to a URL if Missing
+#'
+#' This function ensures that a given URL string ends with a slash ('/'). 
+#' If the URL does not end with a slash, it appends one.
+#'
+#' @param url A character string representing the URL.
+#' @return A character string with a trailing slash if it was missing.
+#' @importFrom stringr str_ends
+.add_slash_if_missing <- function(url) {
+  if(!str_ends(url, "/")) {
+    url <- paste0(url, "/")
+  }
+  return(url)
 }
 
 #' Creates JSON body for the API request
